History
=======

0.15.2 (2020-08-13)
-------------------

* Update STPT viewer

0.15.1 (2020-06-05)
-------------------

* Add support for scikit-image 0.17

0.15.0 (2020-06-02)
-------------------

* Add alpha version of STPT viewer

0.14.1 (2020-02-01)
-------------------

* Update to latest zarr

0.14.0 (2020-01-14)
-------------------

* Add function to read dax files

0.13.0 (2019-11-19)
-------------------

* Reverse mutual information offset indexes.
* Add function to find offsets using minimization. 

0.12.3 (2019-11-03)
-------------------

* Add mutual information to cross correlation.
* Add bytescale function from scipy.
* TiffImage works now well with dask.
* Deprecate image module in favour of io.

